Fix the bitmask for the hour field in a DOS-format time (not that it
[obnox/wireshark/wip.git] / util.c
diff --git a/util.c b/util.c
index 50d38a9726bce34591f47f995656d419bfb55dcf..25d3d2ebc795582354e58460e4793b711b55f7be 100644 (file)
--- a/util.c
+++ b/util.c
@@ -1,6 +1,8 @@
 /* util.c
  * Utility routines
  *
+ * $Id: util.c,v 1.7 1998/10/28 21:22:33 gerald Exp $
+ *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
  * Copyright 1998 Gerald Combs
 
 #include <gtk/gtk.h>
 
+#include <stdarg.h>
 #include <strings.h>
 
+#ifdef NEED_SNPRINTF_H
+# ifdef HAVE_STDARG_H
+#  include <stdarg.h>
+# else
+#  include <varargs.h>
+# endif
+# include "snprintf.h"
+#endif
+
 #include "util.h"
 
+#include "image/icon-excl.xpm"
+#include "image/icon-ethereal.xpm"
+
 const gchar *bm_key = "button mask";
 
 /* Simple dialog function - Displays a dialog box with the supplied message
  * text.
  * 
  * Args:
* type     : One of ESD_TYPE_*.  Currently ignored.
* btn_mask : The address of a gint.  The value passed in determines if
*            the 'Cancel' button is displayed.  The button pressed by the 
*            user is passed back.
* message  : The text displayed in the dialog.
  *
- * To do:
- * - Switch to variable args
  */
+#define ESD_MAX_MSG_LEN 1024
 void
-simple_dialog(gint type, gint *btn_mask, gchar *message) {
+simple_dialog(gint type, gint *btn_mask, gchar *msg_format, ...) {
   GtkWidget   *win, *main_vb, *top_hb, *type_pm, *msg_label,
               *bbox, *ok_btn, *cancel_btn;
   GdkPixmap   *pixmap;
   GdkBitmap   *mask;
   GtkStyle    *style;
   GdkColormap *cmap;
-  
+  va_list      ap;
+  gchar        message[ESD_MAX_MSG_LEN];
+  gchar      **icon;
+
   /* Main window */
   win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_container_border_width(GTK_CONTAINER(win), 7);
-  gtk_window_set_title(GTK_WINDOW(win), "Ethereal: Warning");
+
+  switch (type) {
+  case ESD_TYPE_WARN :
+    gtk_window_set_title(GTK_WINDOW(win), "Ethereal: Warning");
+    icon = icon_excl_xpm;
+    break;
+  case ESD_TYPE_CRIT :
+    gtk_window_set_title(GTK_WINDOW(win), "Ethereal: Critical");
+    icon = icon_excl_xpm;
+    break;
+  case ESD_TYPE_INFO :
+  default :
+    icon = icon_ethereal_xpm;
+    gtk_window_set_title(GTK_WINDOW(win), "Ethereal: Information");
+    break;
+  }
+
   gtk_object_set_data(GTK_OBJECT(win), bm_key, btn_mask);
 
   /* Container for our rows */
@@ -70,18 +105,23 @@ simple_dialog(gint type, gint *btn_mask, gchar *message) {
   gtk_widget_show(main_vb);
 
   /* Top row: Icon and message text */
-  top_hb = gtk_hbox_new(FALSE, 5);
+  top_hb = gtk_hbox_new(FALSE, 10);
   gtk_container_add(GTK_CONTAINER(main_vb), top_hb);
   gtk_widget_show(top_hb);
   
   style = gtk_widget_get_style(win);
   cmap  = gdk_colormap_get_system();
   pixmap = gdk_pixmap_colormap_create_from_xpm_d(NULL, cmap,  &mask,
-    &style->bg[GTK_STATE_NORMAL], icon_excl_xpm);
+    &style->bg[GTK_STATE_NORMAL], icon);
   type_pm = gtk_pixmap_new(pixmap, mask);
+  gtk_misc_set_alignment (GTK_MISC (type_pm), 0.5, 0.0);
   gtk_container_add(GTK_CONTAINER(top_hb), type_pm);
   gtk_widget_show(type_pm);
 
+  /* Load our vararg list into the message string */
+  va_start(ap, msg_format);
+  vsnprintf(message, ESD_MAX_MSG_LEN, msg_format, ap);
+
   msg_label = gtk_label_new(message);
   gtk_label_set_justify(GTK_LABEL(msg_label), GTK_JUSTIFY_FILL);
   gtk_container_add(GTK_CONTAINER(top_hb), msg_label);
@@ -106,6 +146,7 @@ simple_dialog(gint type, gint *btn_mask, gchar *message) {
     gtk_signal_connect(GTK_OBJECT(cancel_btn), "clicked",
       GTK_SIGNAL_FUNC(simple_dialog_cancel_cb), (gpointer) win);
     gtk_container_add(GTK_CONTAINER(bbox), cancel_btn);
+    GTK_WIDGET_SET_FLAGS(cancel_btn, GTK_CAN_DEFAULT);
     gtk_widget_show(cancel_btn);
   }
@@ -1,6 +1,8 @@
  * 
  * Args:
- * type     : One of ESD_TYPE_*.  Currently ignored.
- * btn_mask : The address of a gint.  The value passed in determines if
- *            the 'Cancel' button is displayed.  The button pressed by the 
- *            user is passed back.
- * message  : The text displayed in the dialog.
+ * type       : One of ESD_TYPE_*.
+ * btn_mask   : The address of a gint.  The value passed in determines if
+ *              the 'Cancel' button is displayed.  The button pressed by the 
+ *              user is passed back.
+ * msg_format : Sprintf-style format of the text displayed in the dialog.
+ * ...        : Argument list for msg_format
  *